@@ -56,7 +56,8 @@ GHashTable *mgdg_config_files = NULL;
 /* Every user visible function must have an entry in midgard_functions[].
  */
 #include "php_midgard_functions.h"
-function_entry midgard2_functions[] = {
+
+zend_function_entry midgard2_functions[] = {
 	PHP_FE(mgd_version, NULL)
 	PHP_FE(mgd_is_guid, NULL)
 	/* Undocumented */
@@ -377,6 +378,7 @@ PHP_MINIT_FUNCTION(midgard2)
 	PHP_MINIT(midgard2_reflector_object)(INIT_FUNC_ARGS_PASSTHRU);
 	PHP_MINIT(midgard2_reflector_property)(INIT_FUNC_ARGS_PASSTHRU);
 	PHP_MINIT(midgard2_repligard)(INIT_FUNC_ARGS_PASSTHRU);
+	PHP_MINIT(midgard2_query_selectors)(INIT_FUNC_ARGS_PASSTHRU);
 
 	/* Register midgard_metadata class */
 	static zend_class_entry midgard_metadata_class_entry;
@@ -487,11 +489,11 @@ static PHP_GINIT_FUNCTION(midgard2)
 	midgard2_globals->midgard_global_holder = NULL;
 }
 
-static void __free_connections(gpointer key, gpointer val, gpointer ud)
+/* static void __free_connections(gpointer key, gpointer val, gpointer ud)
 {
 	MidgardConnection *cnc = MIDGARD_CONNECTION(val);
 	g_object_unref(cnc);
-}
+} */
 
 PHP_MSHUTDOWN_FUNCTION(midgard2_urlwrapper);
 PHP_MSHUTDOWN_FUNCTION(midgard2)
