@@ -156,11 +156,18 @@ PHP_FUNCTION(_php_midgard_object_parameter);
 PHP_FUNCTION(_php_midgard_object_connect);
 
 /* Underlying GObject bindings */
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+zval *php_midgard_gobject_read_property(zval *zobject, zval *prop, int type, const zend_literal *key TSRMLS_DC);
+zval **php_midgard_gobject_get_property_ptr_ptr(zval *object, zval *member, const zend_literal *key TSRMLS_DC);
+void php_midgard_gobject_write_property(zval *zobject, zval *prop, zval *value, const zend_literal *key TSRMLS_DC);
+int php_midgard_gobject_has_property(zval *zobject, zval *prop, int type, const zend_literal *key TSRMLS_DC);
+#else
 zval *php_midgard_gobject_read_property(zval *zobject, zval *prop, int type TSRMLS_DC);
 zval **php_midgard_gobject_get_property_ptr_ptr(zval *object, zval *member TSRMLS_DC);
 void php_midgard_gobject_write_property(zval *zobject, zval *prop, zval *value TSRMLS_DC);
-// void php_midgard_zendobject_register_properties (zval *zobject, GObject *gobject);
 int php_midgard_gobject_has_property(zval *zobject, zval *prop, int type TSRMLS_DC);
+#endif
+
 HashTable *php_midgard_zendobject_get_properties (zval *zobject TSRMLS_DC);
 
 void php_midgard_array_from_objects(GObject **objects, const gchar *class_name, zval *zarray TSRMLS_DC);
@@ -224,6 +231,7 @@ PHP_MINIT_FUNCTION(midgard2_base_interface);
 PHP_MINIT_FUNCTION(midgard2_reflector_object);
 PHP_MINIT_FUNCTION(midgard2_reflector_property);
 PHP_MINIT_FUNCTION(midgard2_repligard);
+PHP_MINIT_FUNCTION(midgard2_query_selectors);
 
 zend_class_entry *php_midgard_get_baseclass_ptr(zend_class_entry *ce);
 zend_class_entry *php_midgard_get_baseclass_ptr_by_name(const char *name TSRMLS_DC);
@@ -236,6 +244,19 @@ void php_midgard_error_exception_force_throw(MidgardConnection *mgd, gint errcod
 /* Logging */
 void php_midgard_log_errors(const gchar *domain, GLogLevelFlags level, const gchar *msg, gpointer userdata);
 
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+#define CHECK_MGD(handle) \
+{ \
+	if (!handle) { \
+		zend_throw_exception_ex(ce_midgard_error_exception, 0 TSRMLS_CC, "Failed to get connection"); \
+		return; \
+	} \
+	const gchar *_check_cname_space = ""; \
+	const gchar *_check_class_name = get_active_class_name(&_check_cname_space TSRMLS_CC); \
+	g_log(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, " %s%s%s(...)", \
+		_check_class_name, _check_cname_space, get_active_function_name(TSRMLS_C)); \
+}
+#else
 #define CHECK_MGD(handle) \
 { \
 	if (!handle) { \
@@ -247,7 +268,7 @@ void php_midgard_log_errors(const gchar *domain, GLogLevelFlags level, const gch
 	g_log(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, " %s%s%s(...)", \
 		_check_class_name, _check_cname_space, get_active_function_name(TSRMLS_C)); \
 }
-
+#endif
 
 /* RAGNAROEK COMPATIBLE*/
 
@@ -263,6 +284,8 @@ extern zend_class_entry *php_midgard_workspace_storage_class;
 extern zend_class_entry *php_midgard_workspace_class;
 extern zend_class_entry *php_midgard_reflector_object_class;
 extern zend_class_entry *php_midgard_reflector_property_class;
+extern zend_class_entry *php_midgard_query_executor_class;
+extern zend_class_entry *php_midgard_query_constraint_simple_class;
 
 #define __php_objstore_object(instance) ((php_midgard_gobject *)zend_object_store_get_object(instance TSRMLS_CC))
 #define __php_gobject_ptr(instance) (__php_objstore_object(instance)->gobject)
