@@ -79,7 +79,7 @@ ZEND_END_ARG_INFO()
 /* Initialize ZEND&PHP class */
 PHP_MINIT_FUNCTION(midgard2_key_config_context)
 {
-	static function_entry midgard_key_config_context_methods[] = {
+	static zend_function_entry midgard_key_config_context_methods[] = {
 		// PHP_ME(midgard_key_config_context, __construct,     arginfo_midgard_key_config_context___construct,     ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
 		PHP_ME(midgard_key_config_context, list_key_config, arginfo_midgard_key_config_context_list_key_config, ZEND_ACC_PUBLIC)
 		{NULL, NULL, NULL}
@@ -91,7 +91,7 @@ PHP_MINIT_FUNCTION(midgard2_key_config_context)
 	php_midgard_key_config_context_class = zend_register_internal_class(&php_midgard_key_config_context_class_entry TSRMLS_CC);
 
 	php_midgard_key_config_context_class->ce_flags = ZEND_ACC_EXPLICIT_ABSTRACT_CLASS;
-	php_midgard_key_config_context_class->doc_comment = strdup("Abstract class for key-value (ini like) configuration contexts");
+	CLASS_SET_DOC_COMMENT(php_midgard_key_config_context_class, strdup("Abstract class for key-value (ini like) configuration contexts"));
 	php_midgard_key_config_context_class->create_object = php_midgard_gobject_new;
 
 	zend_register_class_alias("midgard_key_config_context", php_midgard_key_config_context_class);
