@@ -516,7 +516,11 @@ PHP_FUNCTION(_php_midgard_new_query_builder)
 	MidgardConnection *mgd = mgd_handle(TSRMLS_C);
 	CHECK_MGD(mgd);
 
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+	const char *_class_name = get_active_class_name(NULL TSRMLS_CC);
+#else
 	char *_class_name = get_active_class_name(NULL TSRMLS_CC);
+#endif
 
 	MidgardQueryBuilder *builder = midgard_query_builder_new(mgd, (gchar *)_class_name);
 
@@ -550,7 +554,11 @@ PHP_FUNCTION(_php_midgard_new_collector)
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "zz", &propname, &zvalue) == FAILURE)
 		return;
 
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+	const char *_class_name = get_active_class_name(NULL TSRMLS_CC);
+#else
 	char *_class_name = get_active_class_name(NULL TSRMLS_CC);
+#endif
 
 	zval *this_class_name = NULL;
 	MAKE_STD_ZVAL(this_class_name);
@@ -572,7 +580,11 @@ PHP_FUNCTION(_php_midgard_new_reflection_property)
 	MidgardConnection *mgd = mgd_handle(TSRMLS_C);
 	CHECK_MGD(mgd);
 
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+	const char *_class_name = get_active_class_name(NULL TSRMLS_CC);
+#else
 	char *_class_name = get_active_class_name(NULL TSRMLS_CC);
+#endif
 
 	MidgardObjectClass *klass = MIDGARD_OBJECT_GET_CLASS_BY_NAME((const gchar *)_class_name);
 	MidgardReflectionProperty *mrp = midgard_reflection_property_new(MIDGARD_DBOBJECT_CLASS(klass));
@@ -733,8 +745,14 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_constructor),
 		ZEND_ACC_PUBLIC | ZEND_ACC_CTOR,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "guid or id", sizeof("guid or id")-1, NULL, 0, 0, 1 /* Allows NULL */, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "guid or id", sizeof("guid or id")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
+#endif
+
 		}, 
 		1,
 		"Creates new empty instance or fetch object's data from storage if argument is of integer or string type. In latter case valid guid is expected. Throws midgard_error_exception on failure"
@@ -744,8 +762,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_get_by_id),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 1 },
+			{ "id", sizeof("id")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "id", sizeof("id")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		1,
 		"Get object which is identified by given id"
@@ -755,8 +778,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_get_by_guid),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 1 },
+			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 
 		1, 
 		"Load data which is identified by given guid into current object"
@@ -766,7 +794,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_update),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		0,
 		"Store object-changes into database"
@@ -776,7 +808,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_create),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		0,
 		"Create object's record in database"
@@ -786,9 +822,15 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_is_in_parent_tree),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "root_id", sizeof("root_id")-1, NULL, 0, 0, 0, 0 },
+			{ "id", sizeof("id")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 2 },
 			{ "root_id", sizeof("root_id")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "id", sizeof("id")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		2,
 		"Check if object identified by 'id' is descendant of object identified by 'root_id'. Traversing is done using 'parent' markers in schema"
@@ -798,9 +840,15 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_is_in_tree),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "root_id", sizeof("root_id")-1, NULL, 0, 0, 0, 0 },
+			{ "id", sizeof("id")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 2 },
 			{ "root_id", sizeof("root_id")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "id", sizeof("id")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		2,
 		"Check if object identified by 'id' is descendant of object identified by 'root_id'. Traversing is done using 'up' markers in schema"
@@ -810,7 +858,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(php_midgard_object_has_dependents),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -818,8 +870,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_delete),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "check_dependencies", sizeof("check_dependencies")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "check_dependencies", sizeof("check_dependencies")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		1,
 		"Mark object's record in database as \"deleted\""
@@ -829,7 +886,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_get_parent),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		0,
 		"returns parent-object, using 'parent' mark in schema"
@@ -839,7 +900,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_list),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -847,8 +912,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_list_children),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "node class name", sizeof("node class name")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "node class name", sizeof("node class name")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -856,8 +926,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_get_by_path),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "path", sizeof("path")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "path", sizeof("path")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -865,7 +940,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_midgard_php_object_parent),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		0,
 		"returns name of class, which is marked as 'parent' in schema"
@@ -875,7 +954,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(php_midgard_object_has_parameters),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -883,8 +966,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_list_parameters),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "domain", sizeof("domain")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "domain", sizeof("domain")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -892,8 +980,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_find_parameters),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -901,8 +994,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_delete_parameters),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -910,8 +1008,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_purge_parameters),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -919,9 +1022,15 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_get_parameter),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "domain", sizeof("domain")-1, NULL, 0, 0, 0, 0 },
+			{ "name", sizeof("name")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 2 },
 			{ "domain", sizeof("domain")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "name", sizeof("name")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 2
 	},
 
@@ -929,10 +1038,17 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_set_parameter),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "domain", sizeof("domain")-1, NULL, 0, 0, 0, 0 },
+			{ "name", sizeof("name")-1, NULL, 0, 0, 0, 0 },
+			{ "value", sizeof("value")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 3 },
 			{ "domain", sizeof("domain")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "name", sizeof("name")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "value", sizeof("value")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 3
 	},
 
@@ -940,10 +1056,17 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_parameter),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "domain", sizeof("domain")-1, NULL, 0, 0, 0, 0 },
+			{ "name", sizeof("name")-1, NULL, 0, 0, 0, 0 },
+			{ "value", sizeof("value")-1, NULL, 0, 0, 0, 0 },	
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 2 },
 			{ "domain", sizeof("domain")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "name", sizeof("name")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "value", sizeof("value")-1, NULL, 0, 0, 0, 0, 0, 0 },	
+#endif
 		}, 
 	},
 
@@ -951,7 +1074,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(php_midgard_object_has_attachments),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -959,7 +1086,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_list_attachments),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -967,8 +1098,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_find_attachments),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -976,8 +1112,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_delete_attachments),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -985,9 +1126,15 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_purge_attachments),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+			{ "delete blob", sizeof("delete blob")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "constraints", sizeof("constraints")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
 			{ "delete blob", sizeof("delete blob")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 2
 	},
 
@@ -995,10 +1142,17 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_create_attachment),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "name", sizeof("name")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+			{ "title", sizeof("title")-1, NULL, 0, 0, 1 /* Allows NULL */, 0 },
+			{ "mimetype", sizeof("mimetype")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "name", sizeof("name")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
 			{ "title", sizeof("title")-1, NULL, 0, 0, 1 /* Allows NULL */, 0, 0, 0 },
 			{ "mimetype", sizeof("mimetype")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 3
 	},
 
@@ -1006,8 +1160,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_serve_attachment),
 		ZEND_ACC_STATIC|ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -1015,8 +1174,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_purge),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+			{ "check_dependencies", sizeof("check_dependencies")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "check_dependencies", sizeof("check_dependencies")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -1024,8 +1188,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_undelete),
 		ZEND_ACC_STATIC|ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -1033,10 +1202,17 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_connect),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "signal", sizeof("signal")-1, NULL, 0, 0, 0, 0 },
+			{ "callback", sizeof("callback")-1, NULL, 0, 0, 0, 0 },
+			{ "user_data", sizeof("user_data")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 2 },
 			{ "signal", sizeof("signal")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "callback", sizeof("callback")-1, NULL, 0, 0, 0, 0, 0, 0 },
 			{ "user_data", sizeof("user_data")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 3
 	},
 
@@ -1044,7 +1220,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_new_query_builder),
 		ZEND_ACC_STATIC|ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1052,7 +1232,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_new_collector),
 		ZEND_ACC_STATIC|ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1060,7 +1244,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_new_reflection_property),
 		ZEND_ACC_STATIC|ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1068,8 +1256,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_set_guid),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "guid", sizeof("guid")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -1077,8 +1270,13 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_emit),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0 },
+			{ "signal", sizeof("signal")-1, NULL, 0, 0, 0, 0 },
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 1 },
 			{ "signal", sizeof("signal")-1, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 1
 	},
 
@@ -1086,7 +1284,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_approve),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1094,7 +1296,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_is_approved),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1102,7 +1308,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_unapprove),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1110,7 +1320,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_lock),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1118,7 +1332,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_is_locked),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1126,7 +1344,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_unlock),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		}, 0
 	},
 
@@ -1134,7 +1356,11 @@ __midgard_php_type_functions[] =
 		ZEND_FN(_php_midgard_object_get_workspace),
 		ZEND_ACC_PUBLIC,
 		{
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+			{ NULL, 0, NULL, 0, 0, 0, 0},
+#else
 			{ NULL, 0, NULL, 0, 0, 0, 0, 0, 0 },
+#endif
 		},
 		0,
 		"Get workspace associated with object. Returned workspace is valid per method call." 
@@ -1212,11 +1438,12 @@ __find_class_by_name (const gchar *name)
 static void 
 __add_method_comments(const char *class_name)
 {
+	/*
 	guint j;
-
+	FIXME, Rewrite for PHP 5.4
 	for (j = 0; __midgard_php_type_functions[j].fname != NULL; j++) {
 		php_midgard_docs_add_method_comment(class_name, __midgard_php_type_functions[j].fname, __midgard_php_type_functions[j].doc_comment);
-	}
+	} */
 }
 
 static void 
@@ -1261,7 +1488,11 @@ __register_php_class(const gchar *class_name, zend_class_entry *parent TSRMLS_DC
 	mgdclass = g_new0(zend_class_entry, 1);
 	mgdclass->name = g_strdup (class_name);
 	mgdclass->name_length = class_name_length;
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+	mgdclass->info.internal.builtin_functions = __functions;
+#else
 	mgdclass->builtin_functions = __functions;
+#endif
 
 	mgdclass->constructor = NULL;
 	mgdclass->destructor = NULL;
@@ -1276,7 +1507,11 @@ __register_php_class(const gchar *class_name, zend_class_entry *parent TSRMLS_DC
 	mgdclass->interfaces = NULL;
 	mgdclass->get_iterator = NULL;
 	mgdclass->iterator_funcs.funcs = NULL;
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+	mgdclass->info.internal.module = NULL;
+#else
 	mgdclass->module = NULL;
+#endif
 	mgdclass->ce_flags = 0;
 
 	// registering class-template as class
@@ -1353,7 +1588,11 @@ static void __register_abstract_php_classes(const gchar *class_name, zend_class_
 	mgdclass = g_new0(zend_class_entry, 1);
 	mgdclass->name = lcn;
 	mgdclass->name_length = strlen(class_name);
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+	mgdclass->info.internal.builtin_functions = NULL;
+#else
 	mgdclass->builtin_functions = NULL;
+#endif
 
 	mgdclass->constructor = NULL;
 	mgdclass->destructor = NULL;
@@ -1368,7 +1607,11 @@ static void __register_abstract_php_classes(const gchar *class_name, zend_class_
 	mgdclass->interfaces = NULL;
 	mgdclass->get_iterator = NULL;
 	mgdclass->iterator_funcs.funcs = NULL;
+#if PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 3
+	mgdclass->info.internal.module = NULL;
+#else
 	mgdclass->module = NULL;
+#endif
 	mgdclass->ce_flags = 0;
 
 	/* registering class-template as class 
