@@ -23,7 +23,7 @@
 static void php_midgard_array_from_constraints(MidgardQueryConstraintSimple **objects, guint n_objects, zval *zarray TSRMLS_DC);
 
 
-zend_class_entry *php_midgard_query_constraint_simple_class;
+zend_class_entry *php_midgard_query_constraint_simple_class = NULL;
 zend_class_entry *php_midgard_query_constraint_class;
 zend_class_entry *php_midgard_query_constraint_group_class;
 
@@ -339,7 +339,7 @@ ZEND_END_ARG_INFO()
 
 PHP_MINIT_FUNCTION(midgard2_query_constraints)
 {
-	static function_entry midgard_query_constraint_simple_methods[] = {
+	static zend_function_entry midgard_query_constraint_simple_methods[] = {
 		PHP_ME(midgard_query_constraint_simple, list_constraints, arginfo_midgard_query_constraint_simple_list_constraints, ZEND_ACC_PUBLIC)
 		{NULL, NULL, NULL}
 	};
@@ -350,11 +350,11 @@ PHP_MINIT_FUNCTION(midgard2_query_constraints)
 	php_midgard_query_constraint_simple_class = zend_register_internal_class(&php_midgard_query_constraint_simple_class_entry TSRMLS_CC);
 	php_midgard_query_constraint_simple_class->ce_flags |= ZEND_ACC_EXPLICIT_ABSTRACT_CLASS;
 	php_midgard_query_constraint_simple_class->create_object = php_midgard_gobject_new;
-	php_midgard_query_constraint_simple_class->doc_comment = strdup("Base class for holding constraint information for midgard_query");
+	CLASS_SET_DOC_COMMENT(php_midgard_query_constraint_simple_class, strdup("Base class for holding constraint information for midgard_query"));
 
 	zend_register_class_alias("midgard_query_constraint_simple", php_midgard_query_constraint_simple_class);
 
-	static function_entry midgard_query_constraint_methods[] = {
+	static zend_function_entry midgard_query_constraint_methods[] = {
 		PHP_ME(midgard_query_constraint, __construct,  arginfo_midgard_query_constraint___construct,  ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
 		PHP_ME(midgard_query_constraint, get_storage,  arginfo_midgard_query_constraint_get_storage,  ZEND_ACC_PUBLIC)
 		PHP_ME(midgard_query_constraint, set_storage,  arginfo_midgard_query_constraint_set_storage,  ZEND_ACC_PUBLIC)
@@ -370,11 +370,11 @@ PHP_MINIT_FUNCTION(midgard2_query_constraints)
 
 	php_midgard_query_constraint_class = zend_register_internal_class_ex(&php_midgard_query_constraint_class_entry, php_midgard_query_constraint_simple_class, "midgard_query_constraint_simple" TSRMLS_CC);
 	php_midgard_query_constraint_class->create_object = php_midgard_gobject_new;
-	php_midgard_query_constraint_class->doc_comment = strdup("Class for holding simple constraint in midgard_query");
+	CLASS_SET_DOC_COMMENT(php_midgard_query_constraint_class, strdup("Class for holding simple constraint in midgard_query"));
 
 	zend_register_class_alias("midgard_query_constraint", php_midgard_query_constraint_class);
 
-	static function_entry midgard_query_constraint_group_methods[] = {
+	static zend_function_entry midgard_query_constraint_group_methods[] = {
 		PHP_ME(midgard_query_constraint_group, __construct,          arginfo_midgard_query_constraint_group___construct,          ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
 		PHP_ME(midgard_query_constraint_group, get_type,             arginfo_midgard_query_constraint_group_get_type,             ZEND_ACC_PUBLIC)
 		PHP_ME(midgard_query_constraint_group, set_type,             arginfo_midgard_query_constraint_group_set_type,             ZEND_ACC_PUBLIC)
@@ -387,7 +387,7 @@ PHP_MINIT_FUNCTION(midgard2_query_constraints)
 
 	php_midgard_query_constraint_group_class = zend_register_internal_class_ex(&php_midgard_query_constraint_group_class_entry, php_midgard_query_constraint_simple_class, "midgard_query_constraint_group" TSRMLS_CC);
 	php_midgard_query_constraint_group_class->create_object = php_midgard_gobject_new;
-	php_midgard_query_constraint_group_class->doc_comment = strdup("Class for holding group of constraints in midgard_query");
+	CLASS_SET_DOC_COMMENT(php_midgard_query_constraint_group_class, strdup("Class for holding group of constraints in midgard_query"));
 
 	zend_register_class_alias("midgard_query_constraint_group", php_midgard_query_constraint_group_class);
 
