@@ -131,7 +131,7 @@ ZEND_END_ARG_INFO()
 
 PHP_MINIT_FUNCTION(midgard2_query_holders)
 {
-	static function_entry midgard_query_holder_methods[] = {
+	static zend_function_entry midgard_query_holder_methods[] = {
 		PHP_ME(midgard_query_holder, get_value, arginfo_midgard_query_holder_get_value, ZEND_ACC_PUBLIC)
 		PHP_ME(midgard_query_holder, set_value, arginfo_midgard_query_holder_set_value, ZEND_ACC_PUBLIC)
 		{NULL, NULL, NULL}
@@ -143,11 +143,11 @@ PHP_MINIT_FUNCTION(midgard2_query_holders)
 	php_midgard_query_holder_class = zend_register_internal_class(&php_midgard_query_holder_class_entry TSRMLS_CC);
 	php_midgard_query_holder_class->ce_flags |= ZEND_ACC_EXPLICIT_ABSTRACT_CLASS;
 	php_midgard_query_holder_class->create_object = php_midgard_gobject_new;
-	php_midgard_query_holder_class->doc_comment = strdup("Base class for holding data-atom in midgard_query");
+	CLASS_SET_DOC_COMMENT(php_midgard_query_holder_class, strdup("Base class for holding data-atom in midgard_query"));
 
 	zend_register_class_alias("midgard_query_holder", php_midgard_query_holder_class);
 
-	static function_entry midgard_query_property_methods[] = {
+	static zend_function_entry midgard_query_property_methods[] = {
 		PHP_ME(midgard_query_property, __construct, arginfo_midgard_query_property___construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
 		{NULL, NULL, NULL}
 	};
@@ -157,11 +157,11 @@ PHP_MINIT_FUNCTION(midgard2_query_holders)
 
 	php_midgard_query_property_class = zend_register_internal_class_ex(&php_midgard_query_property_class_entry, php_midgard_query_holder_class, "midgard_query_holder" TSRMLS_CC);
 	php_midgard_query_property_class->create_object = php_midgard_gobject_new;
-	php_midgard_query_property_class->doc_comment = strdup("Class for holding object-properties");
+	CLASS_SET_DOC_COMMENT(php_midgard_query_property_class, strdup("Class for holding object-properties"));
 
 	zend_register_class_alias("midgard_query_property", php_midgard_query_property_class);
 
-	static function_entry midgard_query_value_methods[] = {
+	static zend_function_entry midgard_query_value_methods[] = {
 		PHP_ME(midgard_query_value, __construct, arginfo_midgard_query_value___construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
 		{NULL, NULL, NULL}
 	};
@@ -171,7 +171,7 @@ PHP_MINIT_FUNCTION(midgard2_query_holders)
 
 	php_midgard_query_value_class = zend_register_internal_class_ex(&php_midgard_query_value_class_entry, php_midgard_query_holder_class, "midgard_query_holder" TSRMLS_CC);
 	php_midgard_query_value_class->create_object = php_midgard_gobject_new;
-	php_midgard_query_value_class->doc_comment = strdup("Class for holding literal data");
+	CLASS_SET_DOC_COMMENT(php_midgard_query_value_class, strdup("Class for holding literal data"));
 
 	zend_register_class_alias("midgard_query_value", php_midgard_query_value_class);
 
