@@ -113,7 +113,7 @@ ZEND_END_ARG_INFO()
 /* Initialize ZEND&PHP class */
 PHP_MINIT_FUNCTION(midgard2_storage)
 {
-	static function_entry midgard_storage_methods[] = {
+	static zend_function_entry midgard_storage_methods[] = {
 		PHP_ME(midgard_storage, create_base_storage,  arginfo_midgard_storage_create_base_storage,  ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
 		PHP_ME(midgard_storage, create_class_storage, arginfo_midgard_storage_create_class_storage, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
 		PHP_ME(midgard_storage, update_class_storage, arginfo_midgard_storage_update_class_storage, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
@@ -127,7 +127,7 @@ PHP_MINIT_FUNCTION(midgard2_storage)
 
 	php_midgard_storage_class = zend_register_internal_class(&php_midgard_storage_class_entry TSRMLS_CC);
 	php_midgard_storage_class->create_object = NULL;
-	php_midgard_storage_class->doc_comment = strdup("Collection of static methods for managing underlying data storage");
+	CLASS_SET_DOC_COMMENT(php_midgard_storage_class, strdup("Collection of static methods for managing underlying data storage"));
 
 	zend_register_class_alias("midgard_storage", php_midgard_storage_class);
 
