@@ -84,7 +84,7 @@ static PHP_METHOD(midgard_query_builder, __construct)
 	php_midgard_gobject *php_gobject = __php_objstore_object(zval_object);
 	/* Set user defined class. We might need it when execute is invoked */
 	php_gobject->user_ce = ce;
-	php_gobject->user_class_name = ce->name;
+	php_gobject->user_class_name = (char *)ce->name;
 }
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mqb___construct, 0, 0, 1)
@@ -371,7 +371,7 @@ ZEND_END_ARG_INFO()
 
 PHP_MINIT_FUNCTION(midgard2_query_builder)
 {
-	static function_entry query_builder_methods[] = {
+	static zend_function_entry query_builder_methods[] = {
 		PHP_ME(midgard_query_builder, __construct,                  arginfo_mqb___construct,                  ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
 		PHP_ME(midgard_query_builder, add_constraint,               arginfo_mqb_add_constraint,               ZEND_ACC_PUBLIC)
 		PHP_ME(midgard_query_builder, add_constraint_with_property, arginfo_mqb_add_constraint_with_property, ZEND_ACC_PUBLIC)
@@ -391,7 +391,7 @@ PHP_MINIT_FUNCTION(midgard2_query_builder)
 	INIT_CLASS_ENTRY(query_builder_class_entry, "MidgardQueryBuilder", query_builder_methods);
 	php_midgard_query_builder_class = zend_register_internal_class(&query_builder_class_entry TSRMLS_CC);
 	php_midgard_query_builder_class->create_object = php_midgard_gobject_new;
-	php_midgard_query_builder_class->doc_comment = strdup("API for building complex data-queries");
+	CLASS_SET_DOC_COMMENT(php_midgard_query_builder_class, strdup("API for building complex data-queries"));
 
 	zend_register_class_alias("midgard_query_builder", php_midgard_query_builder_class);
 
